@@ -84,6 +84,7 @@
 {
   bool newWindow;
   bool noNewWindow = false;
+  bool isUnityThere = false;
   _dontStart = false;
 
   QCoreApplication::setOrganizationName( "Catkin Project" );
@@ -104,8 +105,14 @@
 
 #ifndef DONT_USE_DBUS
   new DBusAdaptor( this );
-  QDBusConnection::sessionBus().registerObject( "/MainApplication", this );
-  QDBusConnection::sessionBus().registerService( "uk.co.blogistan.catkin" );
+
+  QDBusConnection sessionBus = QDBusConnection::sessionBus();
+  sessionBus.registerObject( "/MainApplication", this );
+  sessionBus.registerService( "uk.co.blogistan.catkin" );
+
+  // Now check for presence of Unity
+  QDBusConnectionInterface *interface = sessionBus.interface();
+  isUnityThere = interface->isServiceRegistered( "com.canonical.Unity" ).value();
 #endif
 
   qtm = qobject_cast<Application *>( qApp );
@@ -127,6 +134,11 @@
   connect( newWindowAtStartup, SIGNAL( toggled( bool ) ),
            this, SLOT( setNewWindowAtStartup( bool ) ) );
 
+  // Override the "newWindowAtStartup" setting if Unity has been found
+  QStringList args = QApplication::arguments();
+  if( isUnityThere && !args.contains( "--no-new-window" ) )
+    newWindow = true;
+
   menu = new QMenu;
   menu->addAction( tr( "New entry" ), this, SLOT( newDoc() ) );
   menu->addAction( tr( "Open ..." ), this, SLOT( choose() ) );
@@ -213,13 +225,16 @@ bool SysTrayIcon::handleArguments()
 
   for( i = 1; i < args.size(); i++ ) {
     c = new EditingWindow;
-    if( c->load( args.at( i ), true ) ) {
-      c->setSTI( this );
-      c->show();
-      rv = true;
-    }
-    else {
-      failedFiles.append( args.at( i ) );
+    if( !args.at( i ).startsWith( "--" ) ) {
+      qDebug() << "Opening:" << args.at( i );
+      if( c->load( args.at( i ), true ) ) {
+        c->setSTI( this );
+        c->show();
+        rv = true;
+      }
+      else {
+        failedFiles.append( args.at( i ) );
+      }
     }
   }
   if( failedFiles.size() ) {
